"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Endpoints_1 = require("../../Endpoints");
const APIBase_1 = require("../APIBase");
class GitHubRepositoryAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * Get a info for a repository. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepository(repositoryOwner, repositoryName) {
        const endpoint = Endpoints_1.Endpoint.GitHub.Repository.repository(repositoryOwner, repositoryName);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Get a list of dependencies for a repositories. Currently only works for open source repositories.
     * @see https://libraries.io/api#repository-dependencies
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     */
    getRepositoryWithDependencies(repositoryOwner, repositoryName) {
        const endpoint = Endpoints_1.Endpoint.GitHub.Repository.dependencies(repositoryOwner, repositoryName);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Get a list of packages referencing the given repository.
     * @see https://libraries.io/api#repository-projects
     * @param repositoryOwner The repository owner
     * @param repositoryName The repository name
     * @param options Pagination Options
     */
    getProjects(repositoryOwner, repositoryName, options) {
        const endpoint = Endpoints_1.Endpoint.GitHub.Repository.projects(repositoryOwner, repositoryName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
}
exports.GitHubRepositoryAPI = GitHubRepositoryAPI;
//# sourceMappingURL=GitHubRepositoryAPI.js.map