"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Endpoints_1 = require("../../Endpoints");
const APIBase_1 = require("../APIBase");
class GitHubUserAPI extends APIBase_1.APIBase {
    constructor(apiClient, options) {
        super(apiClient, options);
    }
    /**
     * Get information for a given user or organization.
     * @see https://libraries.io/api#user
     * @param userName The username
     */
    getUser(userName) {
        const endpoint = Endpoints_1.Endpoint.GitHub.User.user(userName);
        return this.apiClient.requestService.get(endpoint);
    }
    /**
     * Get repositories owned by a user.
     * @see https://libraries.io/api#user-repositories
     * @param userName The username
     * @param options Pagination options
     */
    getRepositories(userName, options) {
        const endpoint = Endpoints_1.Endpoint.GitHub.User.repositories(userName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get a list of packages referencing the given user's repositories.
     * @see https://libraries.io/api#user-projects
     * @param userName The username
     * @param options Pagination options
     */
    getProjects(userName, options) {
        const endpoint = Endpoints_1.Endpoint.GitHub.User.repositories(userName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get a list of packages that the given user has contributed to.
     * @see https://libraries.io/api#user-project-contributions
     * @param userName The username
     * @param options Pagination options
     */
    getContributedProjects(userName, options) {
        const endpoint = Endpoints_1.Endpoint.GitHub.User.contributedProjects(userName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get a list of repositories that the given user has contributed to.
     * @see https://libraries.io/api#user-repository-contributions
     * @param userName The username
     * @param options Pagination options
     */
    getContributedRepositories(userName, options) {
        const endpoint = Endpoints_1.Endpoint.GitHub.User.contributedRepositories(userName);
        return this.apiClient.requestService.get(endpoint, { data: options });
    }
    /**
     * Get a list of unique packages that the given user's repositories list as a dependency. Ordered by frequency of use in those repositories.
     * @see https://libraries.io/api#user-dependencies
     * @param userName The username
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param options Pagination options
     */
    getDependencies(userName, platformOrOptions, options) {
        const endpoint = Endpoints_1.Endpoint.GitHub.User.contributedRepositories(userName);
        let parameters = {};
        if (platformOrOptions) {
            if (typeof platformOrOptions === 'string') {
                parameters = Object.assign({ platform: platformOrOptions }, options);
            }
            else {
                parameters = platformOrOptions;
            }
        }
        return this.apiClient.requestService.get(endpoint, { data: parameters });
    }
}
exports.GitHubUserAPI = GitHubUserAPI;
//# sourceMappingURL=GitHubUserAPI.js.map